@@ -190,7 +190,9 @@ static inline struct key *
 afs_linux_key_alloc(struct key_type *type, const char *desc, afs_kuid_t uid,
 		    afs_kgid_t gid, key_perm_t perm, unsigned long flags)
 {
-# if defined(KEY_ALLOC_NEEDS_STRUCT_TASK)
+# if defined(KEY_ALLOC_BYPASS_RESTRICTION)
+    return key_alloc(type, desc, uid, gid, current_cred(), perm, flags, NULL);
+# elif defined(KEY_ALLOC_NEEDS_STRUCT_TASK)
     return key_alloc(type, desc, uid, gid, current, perm, flags);
 # elif defined(KEY_ALLOC_NEEDS_CRED)
     return key_alloc(type, desc, uid, gid, current_cred(), perm, flags);
