@@ -79,6 +79,9 @@
 #define SYS_NAME_ID_x86_darwin_140       526
 #define SYS_NAME_ID_amd64_darwin_140     527
 #define SYS_NAME_ID_arm_darwin_140       528
+#define SYS_NAME_ID_x86_darwin_150       529
+#define SYS_NAME_ID_amd64_darwin_150     530
+#define SYS_NAME_ID_arm_darwin_150       531
 
 #define SYS_NAME_ID_next_mach20		 601
 #define SYS_NAME_ID_next_mach30		 602
@@ -217,8 +220,10 @@
 #define SYS_NAME_ID_i386_fbsd_91        2122
 #define SYS_NAME_ID_i386_fbsd_92        2124
 #define SYS_NAME_ID_i386_fbsd_93        2126
-#define SYS_NAME_ID_i386_fbsd_100      2130
-#define SYS_NAME_ID_i386_fbsd_101      2131
+#define SYS_NAME_ID_i386_fbsd_100      2150
+#define SYS_NAME_ID_i386_fbsd_101      2151
+#define SYS_NAME_ID_i386_fbsd_102      2152
+#define SYS_NAME_ID_i386_fbsd_103      2153
 #define SYS_NAME_ID_i386_fbsd_110      2140
 
 #define SYS_NAME_ID_ia64_linux2		2200
@@ -323,8 +328,10 @@
 #define SYS_NAME_ID_amd64_fbsd_91       3022
 #define SYS_NAME_ID_amd64_fbsd_92       3023
 #define SYS_NAME_ID_amd64_fbsd_93       3024
-#define SYS_NAME_ID_amd64_fbsd_100     3030
-#define SYS_NAME_ID_amd64_fbsd_101     3031
+#define SYS_NAME_ID_amd64_fbsd_100     3050
+#define SYS_NAME_ID_amd64_fbsd_101     3051
+#define SYS_NAME_ID_amd64_fbsd_102     3052
+#define SYS_NAME_ID_amd64_fbsd_103     3053
 #define SYS_NAME_ID_amd64_fbsd_110     3040
 
 #define SYS_NAME_ID_amd64_w2k           3400
