@@ -407,7 +407,7 @@ scout_initDiskLightObjects(struct mini_line *a_line, struct gwin *a_win)
 	curr_disk->prev = i - 1;
 	curr_disk->next = i + 1;
 	curr_disk->active = 0;
-	curr_disk->name = '\0';
+	curr_disk->name = "";
 
 	/*
 	 * Bump up to the next disk structure.
