@@ -274,12 +274,17 @@ ReadString(struct iod *iodp, char *to, int maxa)
     }
 }
 
-static void
-ReadByteString(struct iod *iodp, byte * to,
-	       int size)
+static int
+ReadByteString(struct iod *iodp, byte * to, int size)
 {
-    while (size--)
-	*to++ = iod_getc(iodp);
+    int nbytes = 0;
+    int c;
+
+    while (size-- > 0 && (c = iod_getc(iodp)) != EOF) {
+	*to++ = c;
+	nbytes++;
+    }
+    return nbytes;
 }
 
 /*
@@ -1040,7 +1045,21 @@ DumpDumpHeader(struct iod *iodp, Volume * vp,
     if (!code)
 	code = DumpString(iodp, 'n', V_name(vp));
     dumpTimes[0] = fromtime;
-    dumpTimes[1] = V_backupDate(vp);	/* Until the time the clone was made */
+    switch (V_type(vp)) {
+    case readwriteVolume:
+	dumpTimes[1] = V_updateDate(vp);	/* until last update */
+	break;
+    case readonlyVolume:
+	dumpTimes[1] = V_creationDate(vp);	/* until clone was updated */
+	break;
+    case backupVolume:
+	/* until backup was made */
+	dumpTimes[1] = V_backupDate(vp) != 0 ? V_backupDate(vp) :
+					       V_creationDate(vp);
+	break;
+    default:
+	code = EINVAL;
+    }
     if (!code)
 	code = DumpArrayInt32(iodp, 't', (afs_uint32 *) dumpTimes, 2);
     return code;
@@ -1081,7 +1100,11 @@ DumpVnode(struct iod *iodp, struct VnodeDiskObject *v, int volid,
     if (!code)
 	code = DumpInt32(iodp, 's', v->serverModifyTime);
     if (v->type == vDirectory) {
-	acl_HtonACL(VVnodeDiskACL(v));
+	code = acl_HtonACL(VVnodeDiskACL(v));
+	if (code) {
+	    Log("DumpVnode: Skipping invalid acl vnode %u (volume %i)\n",
+		 vnodeNumber, volid);
+	}
 	if (!code)
 	    code =
 		DumpByteString(iodp, 'A', (byte *) VVnodeDiskACL(v),
@@ -1339,6 +1362,7 @@ ReadVnodes(struct iod *iodp, Volume * vp, int incremental,
     FdHandle_t *fdP;
     Inode nearInode AFS_UNUSED;
     afs_int32 critical = 0;
+    int nbytes;
 
     tag = iod_getc(iodp);
     V_pref(vp, nearInode);
@@ -1404,9 +1428,18 @@ ReadVnodes(struct iod *iodp, Volume * vp, int incremental,
 		    return VOLSERREAD_DUMPERROR;
 		break;
 	    case 'A':
-		ReadByteString(iodp, (byte *) VVnodeDiskACL(vnode),
+		nbytes = ReadByteString(iodp, (byte *) VVnodeDiskACL(vnode),
 			       VAclDiskSize(vnode));
-		acl_NtohACL(VVnodeDiskACL(vnode));
+		if (nbytes != VAclDiskSize(vnode)) {
+		    Log("ReadVnodes: could not read acl for vnode %lu in dump.\n",
+			 (unsigned long)vnodeNumber);
+		    return VOLSERREAD_DUMPERROR;
+		}
+		if (acl_NtohACL(VVnodeDiskACL(vnode)) != 0) {
+		    Log("ReadVnodes: invalid acl for vnode %lu in dump.\n",
+			 (unsigned long)vnodeNumber);
+		    return VOLSERREAD_DUMPERROR;
+		}
 		break;
 	    case 'h':
 	    case 'f':{
